%global	modname	cysignals

Name:		python-%{modname}
Version:	1.3.2
Release:	1%{?dist}
Summary:	Interrupt and signal handling for Cython
License:	GPLv2+
Source0:	https://github.com/sagemath/%{modname}/releases/download/%{version}/%{modname}-%{version}.tar.bz2
BuildRequires:	pari-devel

%global _description \
When writing Cython code, special care must be taken to ensure that the\
code can be interrupted with CTRL-C. Since Cython optimizes for speed,\
Cython normally does not check for interrupts. For example, code like\
the following cannot be interrupted in Cython:\
\
while True:\
    pass\
\
The cysignals package provides mechanisms to handle interrupts\
(and other signals and errors) in Cython code.\
\
See http://cysignals.readthedocs.org/ for the full documentation.

%description	%{_description}

%package	-n python2-%{modname}
Summary:	%{summary}
%{?python_provide:%python_provide python2-%{modname}}
BuildRequires:  python2-devel
BuildRequires:	python2-Cython
%description	-n python2-%{modname} %{_description}

%package	-n python3-%{modname}
Summary:	%{summary}
BuildRequires:  python3-devel
BuildRequires:	python3-Cython
%description	-n python3-%{modname} %{_description}

%package	doc
Summary:        Documentation for %{name}
BuildRequires:  python-sphinx
%description	doc
Documentation and examples for %{name}.

%prep
%setup -q -n %{modname}-%{version}
if [ %{__isa_bits} = "64" ]; then
    for file in $(find . -name cysignals-CSI); do
	sed -i "s/'lib'/'%{_lib}'/" $file
    done
fi

%build
%py2_build
%py3_build
pushd docs
    %__make html
popd

%install
%py2_install
%py3_install
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -farp docs/build/html %{buildroot}%{_docdir}/%{name}
# Make $_bindir files have same content
sed -i 's@^\(#!/usr/bin/python\)3\( -s\)@\1\2@' %{buildroot}%{_bindir}/cysignals-CSI
cp -p build/src/cysignals/{debug.h,signals.h,signals_api.h} \
    %{buildroot}%{python2_sitearch}/cysignals

%check
PYTHONPATH=%{buildroot}%{python2_sitearch} %{__python2} rundoctests.py src/cysignals/*.pyx
# FIXME does not work
%if 0
PYTHONPATH=%{buildroot}%{python3_sitearch} %{__python3} rundoctests.py src/cysignals/*.pyx
%endif

%files		-n python2-%{modname}
%license LICENSE
%doc PKG-INFO README.rst
%{_bindir}/cysignals-CSI
%{_bindir}/cysignals-CSI-helper.py
%{python2_sitearch}/cysignals
%{python2_sitearch}/cysignals-*.egg-info

%files		-n python3-%{modname}
%license LICENSE
%doc PKG-INFO README.rst
%{_bindir}/cysignals-CSI
%{_bindir}/cysignals-CSI-helper.py
%{python3_sitearch}/cysignals
%{python3_sitearch}/cysignals-*.egg-info

%files		doc
%{_docdir}/%{name}/html
